# <img src="https://www.akashtrehan.com/assets/images/emoji/terminal.png" height="42" align="center"> Kekik

[![Boyut](https://img.shields.io/github/repo-size/keyiflerolsun/Kekik?logo=git&logoColor=white&label=Boyut)](#)
[![Görüntülenme](https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https://github.com/keyiflerolsun/Kekik&title=Görüntülenme)](#)
<a href="https://KekikAkademi.org/Kahve" target="_blank"><img src="https://img.shields.io/badge/☕️-Kahve Ismarla-ffdd00" title="☕️ Kahve Ismarla" style="padding-left:5px;"></a>

[![PyPI](https://img.shields.io/pypi/v/Kekik?logo=pypi&logoColor=white&label=PyPI)](https://pypi.org/project/Kekik)
[![PyPI - Yüklenme](https://img.shields.io/pypi/dm/Kekik?logo=pypi&logoColor=white&label=Yüklenme)](https://pypi.org/project/Kekik)
[![PyPI - Wheel](https://img.shields.io/pypi/wheel/Kekik?logo=pypi&logoColor=white&label=Wheel)](https://pypi.org/project/Kekik)

[![Python Version](https://img.shields.io/pypi/pyversions/Kekik?logo=python&logoColor=white&label=Python)](#)
[![Lisans](https://img.shields.io/pypi/l/Kekik?logo=gnu&logoColor=white&label=Lisans)](#)
[![Durum](https://img.shields.io/pypi/status/Kekik?logo=windowsterminal&logoColor=white&label=Durum)](#)

[![PyPI Yükle](https://github.com/keyiflerolsun/Kekik/actions/workflows/pypiYukle.yml/badge.svg)](https://github.com/keyiflerolsun/Kekik/actions/workflows/pypiYukle.yml)

*İşlerimizi kolaylaştıracak fonksiyonların el altında durduğu kütüphane..*

[![ForTheBadge made-with-python](https://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)
[![ForTheBadge built-with-love](https://ForTheBadge.com/images/badges/built-with-love.svg)](https://GitHub.com/keyiflerolsun/)

## 🚀 Kurulum

```bash
# Yüklemek
pip install Kekik

# Güncellemek
pip install -U Kekik
```

## <img src="https://i.imgur.com/ETZ1ABF.png" height="24" align="center"> Kullanım

### **[slugify](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/slugify.py)**
```python
from Kekik import slugify

print(slugify("Ömer Faruk Sancak"))

# » omer-faruk-sancak
```

### **[unicode_tr](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/unicode_tr.py)**
```python
from Kekik import unicode_tr

print(unicode_tr(u"izmir istanbul").title())

# » İzmir İstanbul
```

### **[link_ayikla](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/link_islemleri.py)**
```python
from Kekik import link_ayikla

print(link_ayikla("Lorem ipsum dolor sit amet, consectetur adipiscing elit. Praesent ornare nec turpis at mollis. Aenean iaculis metus libero, a rhoncus justo suscipit quis. Suspendisse sodales ante eros. Curabitur sagittis massa lacus, vel placerat turpis aliquet ac. Nulla porta cursus consequat. Etiam tristique vestibulum maximus. Vestibulum scelerisque vehicula ex, non feugiat eros placerat a. Cras eleifend cursus felis. Nullam pulvinar dictum purus, eu lobortis sapien posuere accumsan. Integer suscipit nisi diam, nec gravida eros malesuada a. Sed vestibulum sollicitudin ex ut volutpat. Phasellus non magna sed neque blandit vestibulum vitae nec ante. https://google.com Proin fringilla ligula nec metus sagittis venenatis."))

# ['https://google.com']
```

### **[youtube_link_mi](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/link_islemleri.py)**
```python
from Kekik import youtube_link_mi

print(youtube_link_mi("https://google.com"))

# False
```

### **[okunabilir_byte](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/okunabilir_byte.py)**
```python
from Kekik import okunabilir_byte

print(okunabilir_byte(132456498564))

# 123.36 GB
```

### **[zaman_donustur](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/zaman_donustur.py)**
```python
from Kekik import sure2saniye, zaman_donustur

kac_saniye = sure2saniye("15:23")
print(kac_saniye)
# 923

zaman_donustur(kac_saniye)
# 15 dakika, 23 saniye
```

### **[qr_ver](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/qr_ver.py)**
```python
from Kekik import qr_ver

print(qr_ver("keyiflerolsun"))

                         
#   █▀▀▀▀▀█ ▀▀▀▄▀ █▀▀▀▀▀█  
#   █ ███ █ ▀█ ██ █ ███ █  
#   █ ▀▀▀ █ ▄▄▄██ █ ▀▀▀ █  
#   ▀▀▀▀▀▀▀ ▀▄▀ █ ▀▀▀▀▀▀▀  
#   ▀▄█ ▄ ▀█▄▀▄    █▄▄▀ █  
#   ▀▀▄▄██▀█ ▄▄▀██ ▄▀▄▀▄█  
#     ▀  ▀▀▀███ ▄█▄ █ ▄▀▄  
#   █▀▀▀▀▀█ ▀ ▀▄▀▄  ▀▄▀▄▀  
#   █ ███ █  ▄█▄██▄ ▄▀▄    
#   █ ▀▀▀ █ ▀█▀▄██▀ █▄▀▀▀  
#   ▀▀▀▀▀▀▀ ▀ ▀▀▀   ▀▀  ▀  
```

### **[csv2dict](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/csv2dict.py)**
```python
from Kekik import csv2dict

print(csv2dict('Config/ALICILAR.csv'))

# [{'mail': 'keyiflerolsun@gmail.com', 'isim': 'Ömer Faruk'}, {'mail': 'bakalim@gmail.com', 'isim': ''}]
```

### **[dict2csv](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/dict2csv.py)**
```python
from Kekik import dict2csv

print(dict2csv('Config/ALICILAR.csv', [{'isim': 'Ömer Faruk', 'soyisim': 'Sancak'}, {'isim': 'Kekik', 'soyisim': 'Akademi'}]))

# True
```

### **[dosya2set](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/dosya2set.py)**
```python
from Kekik import dosya2set

print(dosya2set("_config.yml"))

# {'theme: jekyll-theme-cayman', 'show_downloads: false'}
```

### **[proxy_ver](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/proxy_ver.py)**
```python
from Kekik import proxy_ver

print(proxy_ver("Proxiler.txt", "requests"))

# {'http': 'http://keyiflerolsun:KekikAkademi@127.0.0.1:3310', 'https': 'http://keyiflerolsun:KekikAkademi@127.0.0.1:3310'}

print(proxy_ver("Proxiler.txt", "aiohttp"))

# ('http://127.0.0.1:3310', BasicAuth(login='keyiflerolsun', password='KekikAkademi', encoding='utf-8'))

print(proxy_ver("proxiler.txt", "selenium"))

# 127.0.0.1:3310:keyiflerolsun:KekikAkademi
```

### **[kisi_ver](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/kisi_ver.py)**
```python
from Kekik import kisi_ver

print(kisi_ver("tr"))

# {'isim': 'Selami', 'soyisim': 'Tokatlioğlu', 'kullanici_adi': 'Sela27Toka', 'biyografi': 'En bilge adamlar kendi yönlerini takip ederler.', 'profil_resmi': 'tmp/Sela27Toka.jpg'}

print(kisi_ver("en"))

# {'isim': 'Laurel', 'soyisim': 'Blake', 'kullanici_adi': 'Laur42Blak', 'biyografi': 'From little acorns mighty oaks do grow.', 'profil_resmi': 'tmp/Laur42Blak.jpg'}
```

### **[Nesne](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/Nesne.py)**
```python
from Kekik import Nesne

nesne = Nesne({"Merhaba": "Dünya"})

print(nesne)
# Nesne(Merhaba=Dünya)

nesne.gorsel(girinti=0, kademe=1)
'''
Nesne(
        Merhaba=...
)
'''

print(nesne.Merhaba)
# Dünya
```

### **[liste_fetis](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/liste_fetis.py)**
```python
from Kekik import liste_fetis

liste = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]

liste_fetis.n_adete_bol(liste, adet=3)
# [[1, 4, 7, 10], [2, 5, 8], [3, 6, 9]]

liste_fetis.n_er_hale_getir(liste, adet=3)
# [[1, 2, 3], [4, 5, 6], [7, 8, 9], [10]]
```

### **[BIST](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/BIST.py)**
```python
from Kekik import BIST

print(BIST.marketler)
# {'XU100': ['AEFES', 'AGHOL', 'AKBNK', 'AKFGY', 'AKSA', 'AKSEN', 'ALARK', 'ALBRK', 'ALFAS', 'ALKIM', 'ARCLK', 'ASELS', 'ASUZU', 'AYDEM', 'BAGFS', 'BASGZ', 'BERA', 'BIMAS', 'BIOEN', 'BRYAT', 'BUCIM', 'CCOLA', 'CEMTS', 'CIMSA', 'DOAS', 'DOHOL', 'ECILC', 'EGEEN', 'EKGYO', 'ENJSA', 'ENKAI', 'ERBOS', 'EREGL', 'EUREN', 'FENER', 'FROTO', 'GARAN', 'GENIL', 'GESAN', 'GLYHO', 'GSDHO', 'GUBRF', 'GWIND', 'HALKB', 'HEKTS', 'IPEKE', 'ISCTR', 'ISDMR', 'ISGYO', 'IZMDC', 'KARSN', 'KCAER', 'KCHOL', 'KERVT', 'KLRHO', 'KMPUR', 'KONTR', 'KONYA', 'KORDS', 'KOZAA', 'KOZAL', 'KRDMD', 'KZBGY', 'MAVI', 'MGROS', 'ODAS', 'OTKAR', 'OYAKC', 'PETKM', 'PGSUS', 'PSGYO', 'SAHOL', 'SASA', 'SELEC', 'SISE', 'SKBNK', 'SMRTG', 'SNGYO', 'SOKM', 'TAVHL', 'TCELL', 'THYAO', 'TKFEN', 'TKNSA', 'TMSN', 'TOASO', 'TSKB', 'TTKOM', 'TTRAK', 'TUKAS', 'TUPRS', 'TURSG', 'ULKER', 'ULUUN', 'VAKBN', 'VESBE', 'VESTL', 'YKBNK', 'YYLGD', 'ZOREN'], 'XU050': ['AEFES', 'AKBNK', 'AKSA', 'AKSEN', 'ALARK', 'ARCLK', 'ASELS', 'BERA', 'BIMAS', 'DOHOL', 'EGEEN', 'EKGYO', 'ENJSA', 'ENKAI', 'EREGL', 'FROTO', 'GARAN', 'GESAN', 'GUBRF', 'HALKB', 'HEKTS', 'ISCTR', 'ISGYO', 'KCHOL', 'KONTR', 'KORDS', 'KOZAA', 'KOZAL', 'KRDMD', 'MGROS', 'ODAS', 'OYAKC', 'PETKM', 'PGSUS', 'SAHOL', 'SASA', 'SISE', 'SMRTG', 'SOKM', 'TAVHL', 'TCELL', 'THYAO', 'TKFEN', 'TOASO', 'TSKB', 'TTKOM', 'TUPRS', 'VAKBN', 'VESTL', 'YKBNK'], 'XU030': ['AKBNK', 'AKSEN', 'ALARK', 'ARCLK', 'ASELS', 'BIMAS', 'EKGYO', 'ENKAI', 'EREGL', 'FROTO', 'GARAN', 'GUBRF', 'HEKTS', 'ISCTR', 'KCHOL', 'KOZAA', 'KOZAL', 'KRDMD', 'ODAS', 'PETKM', 'PGSUS', 'SAHOL', 'SASA', 'SISE', 'TAVHL', 'TCELL', 'THYAO', 'TOASO', 'TUPRS', 'YKBNK']}

print(BIST.sembol_sorgu("VESBE"))
# {'VESBE': ['XU100']}
```

### **[Domain2IP](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/Domain2IP.py)**
```python
from Kekik import Domain2IP

dm2ip = Domain2IP("soundcloud.com")
konsol.print(dm2ip.bilgi)
# {'domain': 'soundcloud.com', 'ipler': ['18.238.243.19', '18.238.243.27', '18.238.243.62', '18.238.243.79'], 'subnetler': ['18.238.243.0/25']}
```

### **[StringCodec](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/Sifreleme/StringCodec.py)**
```python
import re, json
from Kekik.Sifreleme import StringCodec

veri = r'''
var scx = {"fastly":{"tt":"RmFzdGx5","sx":{"p":[],"t":["nUE0pUZ6Yl92nJEgo3u5YzAioF9zoP92ZKtjMGMuAGRlBN=="]},"order":4}};
'''

scx_data = json.loads(re.findall(r'scx = (.*?);', veri)[0])

link_list = []
for key in list(scx_data.keys()):
    t = scx_data[key]["sx"]["t"]
    if isinstance(t, list):
        link_list.append({key: StringCodec.decode(elem) for elem in t})
    if isinstance(t, dict):
        link_list.append({k: StringCodec.decode(v) for k, v in t.items()})

print(link_list)
# [{'fastly': 'https://vidmoxy.com/fl/v1x0e6a5128'}]
```

### **[AESManager](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/Sifreleme/AESManager.py)**
```python
import re, json
from Kekik.Sifreleme import AESManager

veri = r'''
  $(document).ready(function() {
    bePlayer('S3JScTBsNzMyYlFSMHg4NG5vQXNjUT09', '{"ct":"SjkWeIotWbL6TmnwyhkeLy6wAWvEG1pz8R0g+IsLN6P1vo9WvXuiqqDal5g6FXW3Td+Q+1DIGQAt3sNxydOAr4p3uFxxpVPUwIMwLWzw+5m0ED0tno1KU0\/rCXRwq6ATvmrIqSr+qb95hY0wjm3gfjPsxDn4vJ1fcdiRwrfC38MjfKyJFN3\/n\/xLvNT4vgQJTYTEmNOzFZgEIhsSRFiW1\/8nQCaS\/8Xkw0ySUqLvzSMsVf2SSgXyESxyksn3+kz9KqEI+mQpJFUcLSBz8VKXly+tEcYGpTQChzceyudkZcEGvppKheBAarEQ6e3eR9d04gQcFpEaV+QmHODvI1Ql\/pJ1FSAh9F5ZDtF00XDSLZbIEt00PWRkgfc3kxuNQzcC1C6BULNdoGwHbvo5W6uUsMwxG+sn+EH7B7jWtyhx5VHKpIfkyrjC10+K\/hG29bkS3YNSTaDxJnTa3jj1usbwwMX0A7wApIlce4rEVgWpO5y1ZuiJ+tEE3kH1InUzT1jfY4Y0KrZ5X+p2nrQhJrDOxfDy\/GhaidNmmpfuzF6Iniko6sCGa0QRbhVB8ZbrC9qFB\/sk47ZOP1IHPY\/jCh4BTFMDCy1Qx1\/PbVLZzNLHju\/cLYRzS0vJp5aqkwg\/QNCo1q5HrxXL32lMLNOcWPRDqyZaMpiYP+LzJPVndLsqGlfKJWETuKonEqc4r4M0Eu\/bTji\/S7zQ7bvEPuT3PyIRWXDffuNSX6+nqWFD8LM\/iNyc1cC3bMi+p0TR3YZu1MlIvxjYPK0lYtDvd+vaYgCotFm0lLsqg5cuw3pGb8jnEfM1VzEqDcBvBTkRKrxIao\/WWdvGf1MCmTsr+nVH0sT8PTrh6XcoG7hV\/+y8XCsEj2LKWtDtfK+RxSztteXYUUUI9NVtCvjlW\/b8+h6u+B\/CNLtrwoDQzKhTVZ1rZbe\/TP+HR7SkMXYqyAX3qqiyi9s+TrcqkxdbAHzkjr0q2DshtUeipcL5HVrdxL28iXqtYMT\/ytsRCQHpnswNGqW+D47VAYtDl4VafSaNGUMPfu6nq4k0\/FrxtYkts4lE9YUkueQHip8eOFO8dxTp8O7+Civt88C45wEjBHqaiN+n6wm1+3xUy2hKX0PD4gvlPuUeoHDbm\/HLUlPYmGw5cCEAskuJRXdW+gnFB6XzVIKrF7OUtd2yLqSLhnWcSFkMJoPDuIezn1D60pMi8LlJKb1HXwbPRRcqh00\/bFNdmodGpwybcaeegvRaCJbDqd6fmQUxG1ir9o5O8st2\/oJ9\/HivYvxi\/sicZYNzFtuZFGC\/ubPK5Ld9RsJb\/RQ9rkTZzhkBnmM=","iv":"2fedfd8ae68165490f274b521d5a3291","s":"74a525e8e5746772"}');
  });
'''

be_player      = re.search(r"bePlayer\('([^']+)',\s*'(\{[^\}]+\})'\);", veri).groups()
be_player_pass = be_player[0]
be_player_data = be_player[1]

print(json.loads(AESManager.decrypt(be_player_data, be_player_pass).replace("\\", "")))
# {'schedule': {'client': 'vast', 'schedule': [{'offset': 'pre', 'tag': ' https://v.adserve.tv/pg/vast.xml', 'skipoffset': '10', 'skipmessage': '{{LANG Skip_Ad}} XX'}]}, 'adsecond': 0, 'bannerad': None, 'title': 'Doraemon', 'description': '1.Sezon 13.Bu00f6lu00fcm', 'video_location': 'https://mucize.online/list/M2EyVVE0elFFTnRIWXFWOHpwenJIUkdyU29Rclg1aEwvc0Q0dE4zajRQa3I2Yi95TVpWbG41T21aTFQ4TnlKUDVCVkUvVFpBMjl3NG94OHhWaWYzZlVCdStSczRXd0FZRUpmSWQraDZjMGZNQTZqY1FOMWhYRUZqZFF2NC9sMlQ5N2JnKzdtTGpKNFdTK2hBSmM1a3JPWitpMkdlVXlRUjMzeG5TbUhxOU44PQ==', 'images': 'https://mucize.online/upload/photos/2023/12/66dfa35da16bb3dab97a866ac31cca239wLRrDBRGtCD68BRF7BsD0RHHQ3.jpg', 'watermark': 'themes/dosyaload/img/logoo.png', 'link': None, 'vast': 'off', 'dwlink': 'https://mucize.online/download/3302', 'exit': False, 'intro': '', 'outro': None, 'video_id': 3302, 'siteurl': None, 'urls': None, 'referer': 'cizgimax.online', 'sitex': ['https://hls.bepeak.net', 'http://localhost'], 'dws': False, 'download': False}
```

### **[Packer](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/Sifreleme/Packer.py)**
```python
import re
from Kekik.Sifreleme import Packer

veri = r'''
        qualityLabels: {"1661":"720p","814":"480p","524":"360p"},
            };
eval(function(p,a,c,k,e,d){e=function(c){return(c<a?'':e(parseInt(c/a)))+((c=c%a)>35?String.fromCharCode(c+29):c.toString(36))};if(!''.replace(/^/,String)){while(c--){d[e(c)]=k[c]||e(c)}k=[function(e){return d[e]}];e=function(){return'\\w+'};c=1};while(c--){if(k[c]){p=p.replace(new RegExp('\\b'+e(c)+'\\b','g'),k[c])}}return p}('1d(17(p,a,c,k,e,d){e=17(c){18(c<a?\'\':e(1D(c/a)))+((c=c%a)>1w?1c.1C(c+29):c.1B(1z))};1a(!\'\'.19(/^/,1c)){1b(c--){d[e(c)]=k[c]||e(c)}k=[17(e){18 d[e]}];e=17(){18\'\\\\w+\'};c=1};1b(c--){1a(k[c]){p=p.19(1y 1x(\'\\\\b\'+e(c)+\'\\\\b\',\'g\'),k[c])}}18 p}(\'G.H=[{"16":M,"D":"\\\\w\\\\2\\\\2\\\\5\\\\y\\\\N\\\\e\\\\e\\\\i\\\\l\\\\x\\\\a\\\\6\\\\P\\\\f\\\\h\\\\y\\\\5\\\\Q\\\\2\\\\x\\\\d\\\\L\\\\9\\\\9\\\\e\\\\1\\\\l\\\\e\\\\8\\\\2\\\\m\\\\4\\\\8\\\\k\\\\b\\\\s\\\\J\\\\k\\\\n\\\\p\\\\v\\\\3\\\\q\\\\A\\\\c\\\\r\\\\3\\\\d\\\\1\\\\d\\\\j\\\\4\\\\E\\\\2\\\\5\\\\7\\\\1\\\\8\\\\j\\\\1\\\\d\\\\1\\\\t\\\\q\\\\b\\\\K\\\\4\\\\s\\\\t\\\\O\\\\b\\\\6\\\\F\\\\W\\\\q\\\\n\\\\V\\\\3\\\\6\\\\6\\\\z\\\\f\\\\c\\\\I\\\\4\\\\1\\\\c\\\\C\\\\6\\\\3\\\\o\\\\w\\\\l\\\\9\\\\r\\\\m\\\\b\\\\a\\\\m\\\\u\\\\B\\\\p\\\\k\\\\5\\\\9\\\\7\\\\v\\\\z\\\\A\\\\B\\\\7\\\\C\\\\u\\\\E\\\\Y\\\\2\\\\L\\\\K\\\\J\\\\7\\\\g\\\\8\\\\3\\\\a\\\\i\\\\5\\\\g\\\\g\\\\h\\\\15\\\\h\\\\i\\\\1\\\\F\\\\j\\\\a\\\\2\\\\1\\\\I\\\\f\\\\o\\\\14\\\\c\\\\n\\\\p\\\\o\\\\3\\\\13\\\\12\\\\4","11":"0","10":"Z","X":"U"}];T S=R(G.H[0].D);\',1F,1G,\'|1H|1I|1J|1u|1L|1E|1v|1p|1t|1f|1g|1h|1i|1N|1j|1k|1e|1m|1n|1o|1l|1q|1r|1s|1M|1K|1O|1P|2e|2f|2g|2h|2i|2m|2j|2k|2l|2c|2n|2o|2p|2q|2r|2s|2t|2u|2d|2b|1Z|28|1Q|1R|1S|1T|1U|1V|1W|1X|2a|1Y|20|21|22|23|24|25|26|27\'.1A(\'|\'),0,{}))',62,155,'|||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||function|return|replace|if|while|String|eval|x65|x69|x5a|x47|x62|x67|x46|x32|x64|x30|x51|x4e|x4f|x41|x38|x7a|x31|x57|35|RegExp|new|36|split|toString|fromCharCode|parseInt|x6d|62|69|x66|x74|x6c|x58|x70|x6b|x2f|x33|x6a|x61|x6f|getLocation|mu|var|none|x37|x71|x4d|x3a|hls|type|label|x72|x76|x52|x6e|default|x77||preload|true|x42|x75|x50|x63|x78|x68|x2e|x4b|x45|x4c|x73|file|x79|x48|jwSetup|sources|x59|x44|x55'.split('|'),0,{}));
var played = 0;
'''

eval_jwSetup = re.compile(r'\};\s*(eval\(function[\s\S]*?)var played = \d+;').findall(veri)[0]
print(Packer.unpack(Packer.unpack(eval_jwSetup)))
# jwSetup.sources=[{"default":true,"file":"\x68\x74\x74\x70\x73\x3a\x2f\x2f\x64\x32\x2e\x69\x6d\x61\x67\x65\x73\x70\x6f\x74\x2e\x62\x75\x7a\x7a\x2f\x66\x32\x2f\x4e\x74\x4f\x31\x4e\x51\x5a\x6a\x44\x51\x41\x6b\x78\x6c\x58\x45\x47\x33\x6c\x62\x66\x62\x30\x31\x79\x74\x70\x57\x66\x4e\x30\x66\x62\x66\x50\x58\x5a\x55\x31\x6a\x50\x77\x5a\x6d\x48\x71\x58\x41\x37\x6c\x6d\x6d\x4b\x67\x47\x59\x31\x66\x47\x42\x6d\x6c\x38\x68\x32\x7a\x33\x4f\x5a\x69\x4f\x63\x4c\x6b\x51\x70\x7a\x57\x78\x4b\x45\x4c\x57\x42\x63\x79\x4d\x74\x75\x55\x44\x57\x46\x4e\x6c\x69\x64\x70\x46\x46\x65\x6e\x65\x64\x66\x48\x30\x69\x74\x66\x59\x67\x38\x52\x47\x41\x6b\x38\x6c\x76\x72\x31","label":"0","type":"hls","preload":"none"}];var mu=getLocation(jwSetup.sources[0].file);
```

### **[CryptoJS](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/Sifreleme/CryptoJS.py)**
```python
import re
from Kekik.Sifreleme import CryptoJS

veri = r'''
<script type="text/javascript">var bytes = CryptoJS.AES.decrypt(" ","U2FsdGVkX18cXVStfM+Jdw9T7n26/DHGVzPllZQ+bzQ=");document.write(bytes.toString(CryptoJS.enc.Utf8));</script>
'''

cryptData = re.search(r"CryptoJS\.AES\.decrypt\(\"(.*)\",\"", veri).group(1)
cryptPass = re.search(r"\",\"(.*)\"\);", veri).group(1)

print(CryptoJS.decrypt(cryptPass, cryptData))
# <!doctypehtml><meta charset=utf-8><meta content="width=device-width,initial-scale=1,maximum-scale=1,user-scalable=no,viewport-fit=cover"name=viewport><meta content=noindex name=robots><title>MolySTREAM</title><style>body,html{background:#000;width:100%;height:100%}*{margin:0;padding:0}#sheplayer{width:100%!important;height:100%!important;z-index:9}</style><style>#playSheila{display:none;position:fixed;width:100%;height:100%;z-index:8;background:#000;background-image:url(https://www.molystream.net/obilet.png);background-size:100% 100%}.playSheilaBtn{position:absolute;background:#000;color:#fff;padding:1em;left:50%;top:50%;transform:translate(-50%,-50%);font-family:Arial;border-radius:10px;font-size:13px;font-weight:700;cursor:pointer}@media only screen and (max-width:600px){.playSheilaBtn{top:60%}}#sheila{background:#000;color:#fff;position:fixed;width:100%;height:100%;z-index:7}.sheilaBtns{height:100%;width:100%;display:flex;align-items:center;justify-content:center;text-align:center}.playBtnSheila{display:flex;flex-direction:column;align-items:center;padding:0 2em;text-align:center;font-family:Arial;cursor:pointer}.playBackBtnSheila{display:flex;flex-direction:column;align-items:center;padding:0 2em;text-align:center;font-family:Arial;cursor:pointer}.sheilaBtns span{padding:1em 0}.sheilaBtns img{width:50px;height:50px}</style><div id=playSheila><div class=playSheilaBtn onclick=load()>Videoyu Başlat</div></div><div id=sheila></div><div id=sheplayer></div><div style=display:none><div class="jw-reset jw-button-color jw-icon jw-icon-rewind jw-icon-inline"aria-label="10 Saniye İleri Sar"role=button tabindex=0 id=icon-forward-desktop><svg class="jw-svg-icon jw-svg-icon-rewind"focusable=false viewBox="0 0 240 240"xmlns=http://www.w3.org/2000/svg><path d=M193.14,131.08a21.57,21.57,0,0,0-17.7-10.6,21.58,21.58,0,0,0-17.7,10.6,44.77,44.77,0,0,0,0,46.3,21.63,21.63,0,0,0,17.7,10.6,21.61,21.61,0,0,0,17.7-10.6A44.77,44.77,0,0,0,193.14,131.08Zm-17.7,47.2c-7.8,0-14.4-11-14.4-24.1s6.6-24.1,14.4-24.1,14.4,11,14.4,24.1S183.34,178.28,175.44,178.28ZM132,188V137l-4.8,4.8-6.8-6.8,13-13a4.8,4.8,0,0,1,8.2,3.4v62.7ZM30.89,52.88H161V33.58c0-5.3,3.6-7.2,8-4.3l41.8,27.9a5.8,5.8,0,0,1,2.7,2.7,6,6,0,0,1-2.7,8L169,95.78c-4.4,2.9-8,1-8-4.3V72.18H45.29v96.4h48.2v19.3H30.79a4.88,4.88,0,0,1-4.8-4.8V57.78A5,5,0,0,1,30.89,52.88Z></path></svg><div class="jw-reset-text jw-tooltip jw-tooltip-forward"dir=auto><div class=jw-text>10 Saniye İleri Sar</div></div></div><div class="jw-reset jw-display-icon-container jw-display-icon-rewind"id=icon-forward-mobile><div class="jw-reset jw-button-color jw-icon jw-icon-rewind"aria-label="10 Saniye İleri Sar"role=button tabindex=0><svg class="jw-svg-icon jw-svg-icon-rewind"focusable=false viewBox="0 0 240 240"xmlns=http://www.w3.org/2000/svg><path d=M193.14,131.08a21.57,21.57,0,0,0-17.7-10.6,21.58,21.58,0,0,0-17.7,10.6,44.77,44.77,0,0,0,0,46.3,21.63,21.63,0,0,0,17.7,10.6,21.61,21.61,0,0,0,17.7-10.6A44.77,44.77,0,0,0,193.14,131.08Zm-17.7,47.2c-7.8,0-14.4-11-14.4-24.1s6.6-24.1,14.4-24.1,14.4,11,14.4,24.1S183.34,178.28,175.44,178.28ZM132,188V137l-4.8,4.8-6.8-6.8,13-13a4.8,4.8,0,0,1,8.2,3.4v62.7ZM30.89,52.88H161V33.58c0-5.3,3.6-7.2,8-4.3l41.8,27.9a5.8,5.8,0,0,1,2.7,2.7,6,6,0,0,1-2.7,8L169,95.78c-4.4,2.9-8,1-8-4.3V72.18H45.29v96.4h48.2v19.3H30.79a4.88,4.88,0,0,1-4.8-4.8V57.78A5,5,0,0,1,30.89,52.88Z></path></svg></div></div></div><script src=https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js></script><script src=https://www.molystream.net/player/jwplayer.js></script><script>jwplayer.key="ITWMv7t88JGzI0xPwW8I0+LveiXX9SWbfdmt0ArUSyc="</script><script src=https://cdn.molystream.org/assets/s.js></script><script>console.clear();var referrer=document.referrer;function UpdateQualityText(){var e=jwplayer().getQualityLevels()[jwplayer().getCurrentQuality()].label;1<e.length&&$("#QualityText").show().html("Aktif Kalite: <b>"+e+"</b>")}function deb(){devtoolsDetector.addListener(function(e,t){e?(t.checkerName&&(window.stop(),location.reload()),console.clear(),window.stop(),location.reload(),document.getElementById("sheplayer").innerHTML="MolySTREAM",window.location.href="/embed/sheila"):(console.clear(),load())}),devtoolsDetector.lanuch()}function load(){var e=document.getElementById("playSheila");e.parentNode.removeChild(e);try{if(localStorage.getItem("11666-5fdde056fb0e9042e29c0a20")){var t=document.createElement("div");t.className="sheilaBtns",t.innerHTML='<div class="playBtnSheila" onclick="loadi(1)"><img src="https://dbx.molystream.org/assets/play.svg"/><span>Başlat</span></div><div class="playBackBtnSheila"  onclick="loadi(2)"><img src="https://dbx.molystream.org/assets/playback.svg"/><span>Devam Et</span></div>',document.getElementById("sheila").appendChild(t)}else loadi("1")}catch(e){loadi("1")}}function loadi(e){document.getElementById("sheila").innerHTML="",console.clear();var t=!1;e&&(t=!0);var a=jwplayer("sheplayer").setup({file:"https://dbx.molystream.org/embed/sheila/11666-5fdde056fb0e9042e29c0a20",tracks:[null,null],type:"application/vnd.apple.mpegurl",playbackRateControls:!0,image:"",autostart:t});a.once("play",function(){try{"2"==e&&a.seek(localStorage.getItem("11666-5fdde056fb0e9042e29c0a20"))}catch(e){}UpdateQualityText()}),a.on("ready",function(){($("#icon-forward-desktop").insertAfter(".jw-icon-rewind:eq(1)"),$("#icon-forward-mobile").insertAfter(".jw-display-icon-display"),$(".jw-display-icon-next").hide(),$("#icon-forward-desktop, #icon-forward-mobile").click(function(){jwplayer().seek(jwplayer().getPosition()+10)}),$(".jw-button-container #icon-forward-desktop").mouseenter(function(){$(".jw-button-container .jw-tooltip-forward").addClass("jw-open")}).mouseleave(function(){$(".jw-button-container .jw-tooltip-forward").removeClass("jw-open")}),0==$("#QualityText").length)&&(new MutationObserver(function(e){$(".jw-flag-user-inactive").length?$("#QualityText").hide():$("#QualityText").show()}).observe(document.querySelector(".jwplayer"),{attributes:!0}),$(".jw-media").prepend('<div id="QualityText" style="display:none; width:170px; height:30px; font: normal 14px arial; line-height:30px; text-align:right; color:#fff; background:#0000; position:absolute; top:30px; right:20px; z-index:5;"></div>'))}),a.on("levelsChanged",function(e,t){UpdateQualityText()}),a.on("levels",function(){1===a.getCurrentQuality()&&a.setCurrentQuality(0),updateQualityText()}),a.on("levelsChanged",function(e,t){updateQualityText()});var o=0;a.on("error",function(e){if(2<o)return!1;o++,setTimeout(function(){a.load(a.getPlaylist())},300)}),a.on("time",function(e){try{localStorage.getItem("11666-5fdde056fb0e9042e29c0a20-all")||localStorage.setItem("11666-5fdde056fb0e9042e29c0a20-all",a.getDuration()),localStorage.setItem("11666-5fdde056fb0e9042e29c0a20",Math.floor(e.position))}catch(e){}}),$(function(){$("body").on("click",".jw-icon-hd .jw-option",function(){0})}),console.clear()}$(".playSheilaBtn").css("border-radius","3px"),$(".playSheilaBtn").css("background","#fff"),$(".playSheilaBtn").css("color","#000"),$("#playSheila").css("background","#000"),$("#playSheila").css("background-image","none"),$("#playSheila").css("background-size","100% 100%"),$("#playSheila").css("display","block"),deb(),setInterval(function(){console.clear()},100)</script>
```

### **[HexCodec](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/Sifreleme/HexCodec.py)**
```python
import re
from Kekik.Sifreleme import HexCodec

veri = r'''
jwSetup.sources=[{"default":true,"file":"\x68\x74\x74\x70\x73\x3a\x2f\x2f\x64\x32\x2e\x69\x6d\x61\x67\x65\x73\x70\x6f\x74\x2e\x62\x75\x7a\x7a\x2f\x66\x32\x2f\x4e\x74\x4f\x31\x4e\x51\x5a\x6a\x44\x51\x41\x6b\x78\x6c\x58\x45\x47\x33\x6c\x62\x66\x62\x30\x31\x79\x74\x70\x57\x66\x4e\x30\x66\x62\x66\x50\x58\x5a\x55\x31\x6a\x50\x77\x5a\x6d\x48\x71\x58\x41\x37\x6c\x6d\x6d\x4b\x67\x47\x59\x31\x66\x47\x42\x6d\x6c\x38\x68\x32\x7a\x33\x4f\x5a\x69\x4f\x63\x4c\x6b\x51\x70\x7a\x57\x78\x4b\x45\x4c\x57\x42\x63\x79\x4d\x74\x75\x55\x44\x57\x46\x4e\x6c\x69\x64\x70\x46\x46\x65\x6e\x65\x64\x66\x48\x30\x69\x74\x66\x59\x67\x38\x52\x47\x41\x6b\x38\x6c\x76\x72\x31","label":"0","type":"hls","preload":"none"}];var mu=getLocation(jwSetup.sources[0].file);
'''

escaped_hex  = re.findall(r'file":"(.*)","label', veri)[0]
print(HexCodec.decode(escaped_hex))
# https://d2.imagespot.buzz/f2/NtO1NQZjDQAkxlXEG3lbfb01ytpWfN0fbfPXZU1jPwZmHqXA7lmmKgGY1fGBml8h2z3OZiOcLkQpzWxKELWBcyMtuUDWFNlidpFFenedfH0itfYg8RGAk8lvr1
```

### **[NaysHash](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/Sifreleme/NaysHash.py)**
```python
from Kekik.Sifreleme import NaysHash

print(NaysHash().generate_xtoken(
    timestamp = 1695076755128,
    endpoint  = "/customer-citizen-info-v3",
    payload   = {
        "birthDay"              : 31,
        "birthMonth"            : 1,
        "birthYear"             : 1990,
        "citizenId"             : "11111111111",
        "customerName"          : "merhaba",
        "customerSurname"       : "dünya",
        "explicitConsentSigned" : True
    },
))
# EygcmEIe3aU0TWIubaQTuBwbrqpY7HFcNDajlSKCT5c=
```

### **[kekik_cache](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/cache.py)**
```python
import Kekik.cache as cache
cache.REDIS_HOST = "127.0.0.1"
cache.REDIS_PORT = 6379
cache.REDIS_DB   = 0
cache.REDIS_PASS = None
kekik_cache      = cache.kekik_cache

@kekik_cache(ttl=5)
def sync_func(x, y):
    time.sleep(1)
    return x + y

@kekik_cache(ttl=5)
async def async_func(x, y):
    await asyncio.sleep(1)
    return x * y
```

### **[dict2json](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/dict2json.py)**
### **[dosya_indir](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/dosya_indir.py)**
### **[benim_hwid](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/hwid_kontrol.py)**
### **[hwid_kontrol](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/hwid_kontrol.py)**
### **[satir_ekle](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/txt_fetis.py)**
### **[satirlar_ekle](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/txt_fetis.py)**
### **[satir_sil](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/txt_fetis.py)**
### **[list2html](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/list2html.py)**
### **[mail_gonder](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/mail_gonder.py)**
### **[terminal_baslik](https://github.com/keyiflerolsun/Kekik/blob/main/Kekik/terminal_baslik.py)**

## 💸 Bağış Yap

**[☕️ Kahve Ismarla](https://KekikAkademi.org/Kahve)**

## 🌐 Telif Hakkı ve Lisans

* *Copyright (C) 2023 by* [keyiflerolsun](https://github.com/keyiflerolsun) ❤️️
* [GNU GENERAL PUBLIC LICENSE Version 3, 29 June 2007](https://github.com/keyiflerolsun/Kekik/blob/master/LICENSE) *Koşullarına göre lisanslanmıştır..*

## ♻️ İletişim

*Benimle iletişime geçmek isterseniz, **Telegram**'dan mesaj göndermekten çekinmeyin;* [@keyiflerolsun](https://t.me/KekikKahve)

##

> **[@KekikAkademi](https://t.me/KekikAkademi)** *için yazılmıştır..*